<?php 
/*  
Plugin Name: z-LightView
Plugin URI: http://www.zaikos.com/wp-plugins/z-lightview/
Version: 1.2.1
Author: <a href="http://www.zaikos.com/blog/">Dave Zaikos</a>
Description: Enables <a href="http://www.nickstakenburg.com/projects/lightview/" title="LightView">LightView</a> for images in posts and pages, including the WordPress gallery introduced in version 2.5.
*/

/*  Copyright 2009  Dave Zaikos  (email : http://www.zaikos.com/blog/contact/)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// Create class if it doesn't exist.

if ( !class_exists("zLightViewPlugin") ) {
	class zLightViewPlugin {

		// Define which extensions are images. Delimited with a vertical bar.

		var $image_extensions = "jpe?g|png|gif|bmp";

		function lvHeaderScripts() {

			// Setup the locaton of this plugin.

			$plugin_location = dirname(plugin_basename(__FILE__));

			// Deregister older JavaScript libraries included with WordPress.	

			wp_deregister_script('prototype');
			wp_deregister_script('scriptaculous-root');
			wp_deregister_script('scriptaculous-effects');

			// Register the new JavaScript libraries.

			wp_register_script('prototype', plugins_url($plugin_location . '/js/prototype.js'), FALSE, '1.6.0.3');
			wp_register_script('scriptaculous-root', plugins_url($plugin_location . '/js/scriptaculous.js'), FALSE, '1.8.2');
			wp_register_script('scriptaculous-effects', plugins_url($plugin_location . '/js/effects.js'), array('scriptaculous-root'), '1.8.2');

			// Enqueue the LightView script (along with its dependancies).

			wp_enqueue_script('lightview', plugins_url($plugin_location . '/js/lightview.js'), array('prototype','scriptaculous-effects'), '2.5', FALSE);
		}

		function lvHeaderStyles() {

			// Enqueue the LightView stylesheet.

			wp_enqueue_style('lightview', plugins_url(dirname(plugin_basename(__FILE__)) . '/css/lightview.css'), '', '2.5', 'screen');			
		}

		function lvHeaderMeta() {

			// Add meta tag for IE8 compatibility mode because IE is stupid.
			// The call to this function is commented out by default because for it to work the wp_head(); call needs
			// to be directly after <head> in the theme's header.php file. Without that, this function is useless.

			echo "<meta http-equiv=\"X-UA-Compatible\" content=\"IE=EmulateIE7\" />\n";
		}


		function normal_lightview($content){

			// Swap out single image links for LightView use.

			return preg_replace('/<a(.*?)href=(.*?).(' . $this->image_extensions . ')"(.*?)>/i', '<a$1href=$2.$3" $4 class="lightview">', $content);
		}

		function gallery_lightview_shortcode($attr) {

			// Replace WP 2.5's gallery with one which uses LightView. Much of this is taken from the WordPress core.

			global $post;

			// Allow plugins/themes to override the default gallery template.

			$output = apply_filters('post_gallery', '', $attr);
			if ( $output != '' )
				return $output;

			// We're trusting author input, so let's at least make sure it looks like a valid orderby statement

			if ( isset( $attr['orderby'] ) ) {
				$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
				if ( !$attr['orderby'] )
					unset( $attr['orderby'] );
			}

			extract(shortcode_atts(array(
				'orderby'    => 'menu_order ASC, ID ASC',
				'id'         => $post->ID,
				'itemtag'    => 'dl',
				'icontag'    => 'dt',
				'captiontag' => 'dd',
				'columns'    => 3,
				'size'       => 'thumbnail',
			), $attr));

			$id = intval($id);
			$attachments = get_children("post_parent=$id&post_type=attachment&post_mime_type=image&orderby={$orderby}");

			if ( empty($attachments) )
				return '';

			if ( is_feed() ) {
				$output = "\n";
				foreach ( $attachments as $id => $attachment )
					$output .= wp_get_attachment_link($id, $size, true) . "\n";
				return $output;
			}

			$listtag = tag_escape($listtag);
			$itemtag = tag_escape($itemtag);
			$captiontag = tag_escape($captiontag);
			$columns = intval($columns);
			$itemwidth = $columns > 0 ? floor(100/$columns) : 100;

			$output = apply_filters('gallery_style', "
				<style type='text/css'>
					.gallery-item {
						width: {$itemwidth}%;
					}
				</style>
				<!-- zLightView gallery shortcode, see http://www.zaikos.com/blog/wp-plugins/ -->
				<div class='gallery'>");

			foreach ( $attachments as $id => $attachment ) {
				$link = wp_get_attachment_link($id, $size, true);

				$link = eregi_replace("<a(.*)href=['\"](.*)['\"]( .*)><img(.*)src=['\"](.*)\.(" . $this->image_extensions . ")['\"](.*)/></a>", "<a\\1href=\"\\5.\\6\" class=\"lightview\" rel=\"gallery[" . $post->ID . "]\"\\3><img\\4src=\"\\5.\\6\"\\7/></a>", $link);
				$link = eregi_replace("<a(.*)href(.*)(-[0-9]{1,3}x[0-9]{1,3})\.(" . $this->image_extensions . ")(.*)><img", "<a\\1href\\2.\\4\\5><img", $link);

				$output .= "<{$itemtag} class='gallery-item'>";
				$output .= "
					<{$icontag} class='gallery-icon'>
						$link
					</{$icontag}>";
				if ( $captiontag && trim($attachment->post_excerpt) ) {
					$output .= "
						<{$captiontag} class='gallery-caption'>
						{$attachment->post_excerpt}
						</{$captiontag}>";
				}
				$output .= "</{$itemtag}>";
				if ( $columns > 0 && ++$i % $columns == 0 )
					$output .= '<br style="clear: both" />';
			}

			$output .= "
					<br style='clear: both;' />
				</div>\n";

			return $output;
		}

		// Check that the Lightview files have been installed properly.

		function init_check_proper_install() {

			// Get the locaton of this plugin.

			$plugin_location = dirname(plugin_basename(__FILE__));

			// Check for the Lightview core.

			if ( !file_exists(WP_PLUGIN_DIR.'/'.$plugin_location.'/css/lightview.css') )
				$check = '<li><code>'.$plugin_location.'/css/lightview.css</code> file.</li>';
			if ( !file_exists(WP_PLUGIN_DIR.'/'.$plugin_location.'/js/lightview.js') )
				$check .= '<li><code>'.$plugin_location.'/js/lightview.js</code> file.</li>';
			if ( !file_exists(WP_PLUGIN_DIR.'/'.$plugin_location.'/images/lightview') )
				$check .= '<li><code>'.$plugin_location.'/images/lightview</code> folder.</li>';

			// If files we're missing, force the plugin to deactivate and throw a fatal error.

			if ( isset($check) ) {
				deactivate_plugins(plugin_basename(__FILE__), TRUE);
				die ('z-Lightview is missing one or more Lightview files (<a href="http://www.nickstakenburg.com/projects/download/?project=lightview" target="_blank">download Lightview</a> to complete the install):<ul>' . $check . '</ul>');
			}
		}
	}
}

// Initialize class.

if ( class_exists("zLightViewPlugin") ) {
	$zlightview_plugin = new zLightViewPlugin();

	// LightView would be sucky on iPhone's or iPod Touch's; so we won't include the headers for those. Also omitted if we're on an admin page.

	if ( !is_admin() && stristr($_SERVER['HTTP_USER_AGENT'], "iPhone") === FALSE && stristr($_SERVER['HTTP_USER_AGENT'], "iPod") === FALSE ) {
		// add_action('wp_head', array(&$zlightview_plugin, 'lvHeaderMeta'), 0);
		add_action('wp_print_scripts', array(&$zlightview_plugin, 'lvHeaderScripts'));
		add_action('wp_print_styles', array(&$zlightview_plugin, 'lvHeaderStyles'));
	}

	remove_shortcode('gallery', 'gallery_shortcode');
	add_shortcode('gallery', array(&$zlightview_plugin, 'gallery_lightview_shortcode'));
	add_filter('the_content', array(&$zlightview_plugin, 'normal_lightview'));
	register_activation_hook(__FILE__, array(&$zlightview_plugin, 'init_check_proper_install'));
}